@@ -10,8 +10,7 @@ use strict;
 use Debian::Debhelper::Dh_Lib;
 
 # see /usr/share/doc/debhelper/PROGRAMMING.gz
-insert_before("dh_install","dh_installdebconf") ;
-insert_after("dh_installdebconf", "dh_cme_upgrade");
+insert_before("dh_install", "dh_cme_upgrade");
 
 
 1;
